@@ -16,9 +16,6 @@ constructs:
     * :class:`Polygon`
     * ...for now
 
-Each of these elements can interact with the other by calculating
-intersections, dividing objects, etc.
-
 Notes
 -----
 Except for the :class:`Point` and :class:`Vector` classes which will be
@@ -40,7 +37,6 @@ import utils as u
 
 
 # acceptable uncertainty for calculating intersections and such
-__version__ = '0.1b'
 UNCERTAINTY = 1e-5
 
 
@@ -50,7 +46,7 @@ def get_perpendicular_to(obj, at_point=None):
     `obj` (:class:`Vector` or :class:`Line`-like) depending on `at_point`
     parameter.
 
-    The perpendicular vector to the obj is not necessarily the unit
+    The perpendicular vector to the `obj` is not necessarily the unit
     :class:`Vector`.
 
     Parameters
@@ -65,10 +61,7 @@ def get_perpendicular_to(obj, at_point=None):
     -------
     out : vector
         A new :class:`Vector` or :class:`Line` passing through `at_point`
-        with the components in such a way it is perpendicular with `obj`. This
-        really means to take the given :class:`Vector` (`obj` itself, or the
-        one from the :class:`Line`-like) and make a new one with components
-        <`obj.y`, `obj.x`>.
+        with the components in such a way it is perpendicular with `obj`..
 
     Raises
     ------
@@ -222,7 +215,7 @@ class Point(GeometricObject):
     ----------
     *args : {two scalars, point-like}, optional
         :class:`Point`-like means that it can be either of `tuple` or `list`
-        of length 2 (see :method:`Point.is_point_like`).
+        of length 2 (see :meth:`Point.is_point_like`).
 
     Raises
     ------
@@ -391,7 +384,7 @@ class Point(GeometricObject):
         Calculate the distance to another :class:`GeometricObject`.
 
         For now it can only calculate the distance to :class:`Line`,
-        :class:`Segment` and :class:`Point`.
+        :class:`Ray` :class:`Segment` and :class:`Point`.
 
         Parameters
         ----------
@@ -1509,7 +1502,7 @@ class Polygon(GeometricObject):
         This variable (`self._area`) is meant to be just for internal use.
         """
 
-        # first add the first vertice to the list
+        # first add the first vertex to the list
         if self._area is None:
             vertices = self.vertices + [self.vertices[0]]
             self._area = 1/2. * sum([v1.x*v2.y - v2.x*v1.y for v1, v2 in \
@@ -1562,17 +1555,17 @@ class Polygon(GeometricObject):
 
     def __getitem__(self, idx):
         """
-        Retreive points (`vertice`) by `idx`.
+        Retreive points (`self.vertices`) by `idx`.
 
         Parameters
         ----------
         idx : scalar
-            The index of the :class:`Point` (`vertice`).
+            The index of the :class:`Point` (`vertex`).
 
         Returns
         -------
         ret : point
-            The `vertice` by index.
+            The `vertex` by index.
         """
         return self.vertices[idx]
 
@@ -1706,12 +1699,12 @@ class Polygon(GeometricObject):
         Parameters
         ----------
         obj : line-like, optional
-            If no `obj` is given then `edge_no` is used to build from a
-            `Ray` from a randomly chosen Point on `self.edges[edge_no]` with
+            If no `obj` is given then `edge_no` is used to build  a :class:`Ray`
+            from a randomly chosen Point on `self.edges[edge_no]` with
             inward direction and the closest intersection :class:`Point` to
             `Ray.p1` is used to divide the :class:`Polygon` in two, else all
             of the points given by the intersection between the
-            :class:`Polygon` and obj are used to split the
+            :class:`Polygon` and `obj` are used to split the
             :class:`Polygon` in any number of polygons.
         edge_no : int, optional
             If given, `self.edges[edge_no]` will be used to build a
